@@ -9,15 +9,16 @@ use Carp qw(carp croak);
 our $VERSION;
 our %Config = (
     AutoReconnect => 0,
-    DebugSQL => 0,
-    QuoteIdentifier => 1,
     CacheQuery => 0,
+    DebugSQL => 0,
+    OnRowUpdate => 'simple',
+    QuoteIdentifier => 1,
 );
 my $need_c3_initialize;
 my @ConnectArgs;
 
 BEGIN {
-    $VERSION = '0.33';
+    $VERSION = '0.34';
     # The C3 method resolution order is required.
     if ($] < 5.009_005) {
         require MRO::Compat;
@@ -463,15 +464,6 @@ Before every operation the connection will be tested via ping() and reconnected
 Changing this has no effect after the connection has been made.
 Defaults to C<false>.
 
-=item C<DebugSQL>
-
-Set to C<1> or C<2> to warn about each SQL command executed.  C<2> adds a full stack trace.
-Defaults to C<0> (silent).
-
-=item C<QuoteIdentifier>
-
-Boolean setting to control quoting of SQL identifiers (schema, table and column names).
-
 =item C<CacheQuery>
 
 Boolean setting to cause C<Query> objects to cache their entire result for re-use.
@@ -479,6 +471,23 @@ The query will only be executed automatically once.
 To rerun the query, either explicitly call L<run|DBIx::DBO::Query/"run"> or alter the query.
 Defaults to C<false>.
 
+=item C<DebugSQL>
+
+Set to C<1> or C<2> to warn about each SQL command executed.  C<2> adds a full stack trace.
+Defaults to C<0> (silent).
+
+=item C<OnRowUpdate>
+
+Set to C<'empty'>, C<'simple'> or C<'reload'> to define the behaviour of a C<Row> after an L<update|DBIx::DBO::Row/"update">.
+C<'empty'> will simply leave the C<Row> empty after every update.
+C<'simple'> will set the values in the C<Row> if they are not complex expressions, otherwise the C<Row> will be empty.
+C<'reload'> is the same as C<'simple'> except it also tries to reload the C<Row> if possible.
+Defaults to C<'simple'>.
+
+=item C<QuoteIdentifier>
+
+Boolean setting to control quoting of SQL identifiers (schema, table and column names).
+
 =item C<UseHandle>
 
 Set to C<'read-write'> or C<'read-only'> to force using only that handle for all operations.
@@ -646,7 +655,7 @@ Please report any bugs or feature requests to C<bug-dbix-dbo AT rt.cpan.org>, or
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2009-2012 Vernon Lyon, all rights reserved.
+Copyright 2009-2013 Vernon Lyon, all rights reserved.
 
 This package is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
 
